<?php

namespace WPSP_PRO;

class Admin
{
    private $free_enabled = false;
    public function __construct()
    {
        $this->load_plugin_pages();
        $this->plugin_licensing();
        $this->admin_notice_loaded();
        add_filter('plugin_action_links_' . WPSP_PRO_PLUGIN_BASENAME, array($this, 'insert_pro_plugin_links'));
        add_action('wpsp/admin/settings/set_settings_config', array($this, 'set_settings_config_callback'));
        add_action( 'wpsp_el_modal_pro_fields', [ $this, 'wpsp_el_modal_pro_fields' ] );
    }

    public function load_plugin_pages()
    {
        new Admin\Menu();
    }



    /**
     * add license module
     */
    public function plugin_licensing()
    {
        // Setup the settings page and validation
        $licensing = new Admin\WPDev\Licensing(
            WPSP_PRO_SL_ITEM_SLUG,
            'SchedulePress',
            'wp-scheduled-posts-pro'
        );
    }



    /**
     * Extending plugin links
     *
     * @since 2.3.1
     */
    public function insert_pro_plugin_links($links)
    {
        // settings
        $links[] = sprintf('<a href="admin.php?page=' . WPSP_PRO_SETTINGS_SLUG . '">' . __('Settings', 'wp-scheduled-posts-pro') . '</a>');

        // go pro
        if (!is_plugin_active('wp-scheduled-posts-pro/wp-scheduled-posts-pro.php')) {
            $links[] = sprintf('<a href="https://wpdeveloper.com/plugins/wp-scheduled-posts/" target="_blank" style="color: #39b54a; font-weight: bold;">' . __('Go Pro', 'wp-scheduled-posts-pro') . '</a>');
        }

        return $links;
    }

    public function admin_notice_loaded()
    {
        $this->free_enabled();
        // version compatibility notice
        if ($this->free_enabled && \version_compare(WPSP_PRO_VERSION, '2.5.3', '<')) {
            add_action('admin_notices', array($this, 'admin_version_compatible_notice'));
        }
    }

    /**
     * Check free is enabled
     */

    public function free_enabled()
    {
        if (function_exists('is_plugin_active')) {
            return $this->free_enabled = is_plugin_active('wp-scheduled-posts/wp-scheduled-posts.php');
        } else {
            if (class_exists('WPSP')) {
                return $this->free_enabled = true;
            }
        }
    }

    public function admin_version_compatible_notice()
    {
        $class = 'notice notice-error';
        $message = __('You are using an incompatible version of', 'wp-scheduled-posts-pro') . '<strong> ' . __('SchedulePress Pro.', 'wp-scheduled-posts-pro') . ' </strong>' . __('Please update to v2.5.3+', 'wp-scheduled-posts-pro');
        printf('<div class="%1$s"><p>%2$s</p></div>', esc_attr($class), $message);
    }


    public function set_settings_config_callback($Builder)
    {
        $Builder::add_field('wpsp_general', [
            'id' => 'is_republish_social_share',
            'type' => 'checkbox',
            'title' => __('Active Republish Social Share', 'wp-scheduled-posts'),
            'default' => false,
        ]);
        // Manage Schedule
        $Builder::add_tab([
            'title' => __('Manage Schedule', 'wp-scheduled-posts-pro'),
            'id' => 'manage_schedule',
        ]);
        // auto schedule
        $Builder::add_group('manage_schedule', [
            'id' => 'auto_schedule',
            'title' => __('Auto Scheduler', 'wp-scheduled-posts-pro'),
            'subtitle'  => 'Enable to publish posts randomly within your given time interval throughout the week.'
        ]);
        $Builder::add_group_field('manage_schedule', 'auto_schedule', [
            'id' => 'is_active_status',
            'type' => 'manageScheduleToggle',
            'title' => __('Auto Schedule', 'wp-scheduled-posts-pro'),
            'default' => true,
        ]);
        $Builder::add_group_field('manage_schedule', 'auto_schedule', [
            'id' => 'sunday_post_limit',
            'type' => 'text',
            'title' => __('Sunday', 'wp-scheduled-posts-pro'),
            'subtitle'  => __('(number of posts)', 'wp-scheduled-posts-pro'),
            'default' => '0',
        ]);
        $Builder::add_group_field('manage_schedule', 'auto_schedule', [
            'id' => 'monday_post_limit',
            'type' => 'text',
            'title' => __('Monday', 'wp-scheduled-posts-pro'),
            'subtitle'  => __('(number of posts)', 'wp-scheduled-posts-pro'),
            'default' => '0',
        ]);
        $Builder::add_group_field('manage_schedule', 'auto_schedule', [
            'id' => 'tuesday_post_limit',
            'type' => 'text',
            'title' => __('Tuesday', 'wp-scheduled-posts-pro'),
            'subtitle'  => __('(number of posts)', 'wp-scheduled-posts-pro'),
            'default' => '0',
        ]);
        $Builder::add_group_field('manage_schedule', 'auto_schedule', [
            'id' => 'wednesday_post_limit',
            'type' => 'text',
            'title' => __('Wednesday', 'wp-scheduled-posts-pro'),
            'subtitle'  => __('(number of posts)', 'wp-scheduled-posts-pro'),
            'default' => '0',
        ]);
        $Builder::add_group_field('manage_schedule', 'auto_schedule', [
            'id' => 'thursday_post_limit',
            'type' => 'text',
            'title' => __('Thursday', 'wp-scheduled-posts-pro'),
            'subtitle'  => __('(number of posts)', 'wp-scheduled-posts-pro'),
            'default' => '0',
        ]);
        $Builder::add_group_field('manage_schedule', 'auto_schedule', [
            'id' => 'friday_post_limit',
            'type' => 'text',
            'title' => __('Friday', 'wp-scheduled-posts-pro'),
            'subtitle'  => __('(number of posts)', 'wp-scheduled-posts-pro'),
            'default' => '0',
        ]);
        $Builder::add_group_field('manage_schedule', 'auto_schedule', [
            'id' => 'saturday_post_limit',
            'type' => 'text',
            'title' => __('Saturday', 'wp-scheduled-posts-pro'),
            'subtitle'  => __('(number of posts)', 'wp-scheduled-posts-pro'),
            'default' => '0',
        ]);
        $Builder::add_group_field('manage_schedule', 'auto_schedule', [
            'id' => 'start_time',
            'type' => 'time',
            'title' => __('Start Time', 'wp-scheduled-posts-pro'),
            'subtitle'  => __('(Default: 12:00 am)', 'wp-scheduled-posts-pro'),
            'default' => '12:00 am',
        ]);
        $Builder::add_group_field('manage_schedule', 'auto_schedule', [
            'id' => 'end_time',
            'type' => 'time',
            'title' => __('End Time', 'wp-scheduled-posts-pro'),
            'subtitle'  => __('(Default: 11:59 pm)', 'wp-scheduled-posts-pro'),
            'default' => '11:59 pm',
        ]);
        // manual schedule
        $Builder::add_group('manage_schedule', [
            'id' => 'manual_schedule',
            'title' => __('Manual Scheduler', 'wp-scheduled-posts-pro'),
            'subtitle'  => 'Get absolute control over your schedule time.'
        ]);
        $Builder::add_group_field('manage_schedule', 'manual_schedule', [
            'id' => 'is_active_status',
            'type' => 'manageScheduleToggle',
            'title' => __('Manual Schedule', 'wp-scheduled-posts-pro'),
            'default' => false,
        ]);
        $Builder::add_group_field('manage_schedule', 'manual_schedule', [
            'id' => 'weekdata',
            'type' => 'scheduletable'
        ]);

        // active missed schedule
        $Builder::add_tab([
            'title' => __('Missed Schedule', 'wp-scheduled-posts-pro'),
            'id' => 'wpsp_pro_miss_schedule',
        ]);
        $Builder::add_field('wpsp_pro_miss_schedule', [
            'id' => 'is_active_missed_schedule',
            'type' => 'MissSchedule',
            'title' => __('Activate Missed Schedule Handler', 'wp-scheduled-posts-pro'),
            'desc'  => __('WordPress might miss the schedule for a post for various reasons. Turn on this option to
            let SchedulePress take care of this and publish the missed schedule.', 'wp-scheduled-posts-pro'),
            'default' => false,
        ]);
        // license
        $Builder::add_tab([
            'title' => __('License', 'wp-scheduled-posts-pro'),
            'id' => 'wpsp_pro_license',
        ]);
        $Builder::add_field('wpsp_pro_license', [
            'id' => 'wp-scheduled-posts-pro-license-key',
            'type' => 'license',
            'default' => false,
        ]);
    }

	public function wpsp_el_modal_pro_fields( $post_id ) {
		$republish_date = get_post_meta( $post_id, '_wpscp_schedule_republish_date', true );
		$unpublish_date = get_post_meta( $post_id, '_wpscp_schedule_draft_date', true );
        ?>
        <div class="wpsp-pro-fields wpsp-pro-activated">
            <label>
                <span><?php esc_html_e( 'Republish On', 'wp-scheduled-posts' ); ?></span>
                <input id="wpsp-republish-datetime" type="text" name="republish_datetime" value="<?php echo esc_attr( $republish_date ) ?>" readonly>
            </label>
            <label>
                <span><?php esc_html_e( 'Unpublish On', 'wp-scheduled-posts' ); ?></span>
                <input id="wpsp-unpublish-datetime" type="text" name="unpublish_datetime" value="<?php echo esc_attr( $unpublish_date ) ?>" readonly>
            </label>
        </div>
		<?php
	}
}
