<?php

namespace WPSP_PRO;

use WPSP_PRO\Traits\Core;
use WPSP_PRO\Traits\Library;

class Installer
{
    use Library;
    use Core;

    public function __construct()
    {
        add_action('plugins_loaded', array($this, 'plugin_redirect'), 90);
    }

    /**
     * Plugin activation hook
     *
     * @since 2.0.0
     */
    public function plugin_activation_hook()
    {
        // make lite version available
        set_transient('wpscp_install_lite', true, 1800);
    }


    /**
     * Plugin upgrader
     *
     * @since v1.0.0
     */
    public function plugin_updater()
    {
        // Disable SSL verification
        add_filter('edd_sl_api_request_verify_ssl', '__return_false');

        // Setup the updater
        $license = get_option(WPSP_PRO_SL_ITEM_SLUG . '-license-key');

        $updater = new Admin\WPDev\Updater(
            WPSP_PRO_STORE_URL,
            WPSP_PRO_PLUGIN_BASENAME,
            [
                'version' => WPSP_PRO_VERSION,
                'license' => $license,
                'item_id' => WPSP_PRO_SL_ITEM_ID,
                'author' => 'WPDeveloper',
            ]
        );
    }

    public function plugin_redirect()
    {
        if (get_option('wpsp_do_activation_redirect', false) && class_exists('WPSP')) {
            delete_option('wpsp_do_activation_redirect');
            wp_safe_redirect(admin_url('admin.php?page=' . WPSP_PRO_SETTINGS_SLUG));
        }
    }

    /**
     * Plugin migrator
     *
     * @since 2.0.0
     */
    public function migrate()
    {
        // db update if version number is changed
        if (version_compare(get_option('wpscp_pro_version'), WPSP_PRO_VERSION, '<')) {
            do_action('wpsp_save_settings_default_value' );
        }

        if(get_option('manage-schedule.php') || Migration::get_manage_schedule_settings()){
            Migration::version_2_to_4();
        }
        
         // migration trick
        if (get_option('wpscp_pro_version') != WPSP_PRO_VERSION) {
            
            // set current version to db
            update_option('wpscp_pro_version', WPSP_PRO_VERSION);
            // make lite version available
            set_transient('wpscp_install_lite', true, 1800);
        }
        // check for lite version
        if (get_transient('wpscp_install_lite')) {
            // install lite version
            $this->make_lite_available();
        }
    }
}
