<?php
/*
 * Plugin Name: SchedulePress Pro (Formerly Known as WP Scheduled Posts Pro)
 * Plugin URI: https://wpdeveloper.com/plugins/wp-scheduled-posts/
 * Description: A complete solution to manage your scheduled posts in WordPress with Auto & Manual Scheduler, Missed Schedule Handler, Republish/Unpublish and many more.
 * Version: 4.1.2
 * Author: WPDeveloper
 * Author URI: https://wpdeveloper.com
 * Text Domain: wp-scheduled-posts-pro
 */


if (!defined('ABSPATH')) exit;

if (file_exists(dirname(__FILE__) . '/vendor/autoload.php')) {
    require_once dirname(__FILE__) . '/vendor/autoload.php';
}
if (file_exists(ABSPATH . 'wp-admin/includes/plugin.php')) {
    include_once(ABSPATH . 'wp-admin/includes/plugin.php');
}


final class WPSP_PRO
{
    private $installer;
    private function __construct()
    {
        $this->define_constants();
        add_action('init',  [$this, 'install_core']);
        register_activation_hook(__FILE__, [$this, 'activate']);
        register_deactivation_hook(__FILE__, [$this, 'deactivate']);
        $this->installer = new WPSP_PRO\Installer();
        add_action('plugins_loaded', [$this, 'init_plugin']);
        add_action('wp_loaded', [$this, 'run_migrator']);
        if (!is_plugin_active('wp-scheduled-posts/wp-scheduled-posts.php')) {
            add_action('admin_notices', array($this, 'core_install_notice'));
        }
    }

    public static function init()
    {
        static $instance = false;

        if (!$instance) {
            $instance = new self();
        }

        return $instance;
    }
    public function define_constants()
    {
        /**
         * Defines CONSTANTS for Whole plugins.
         */
        define('WPSP_PRO_VERSION', '4.1.2');
        define('WPSP_PRO_PLUGIN_BASENAME', plugin_basename(__FILE__));
        define('WPSP_PRO_SETTINGS_SLUG', 'schedulepress');
        define('WPSP_PRO_SETTINGS_NAME', 'wpsp_settings');
        define('WPSP_PRO_PLUGIN_URL', plugins_url('/', __FILE__));
        define('WPSP_PRO_ASSETS_URL', WPSP_PRO_PLUGIN_URL . 'assets/');
        define('WPSP_PRO_ROOT_PATH', plugin_dir_path(__FILE__));
        define('WPSP_PRO_VIEW_DIR_PATH', WPSP_PRO_ROOT_PATH . 'views/');
        define('WPSP_PRO_ASSETS_PATH', WPSP_PRO_ROOT_PATH . 'assets/');
        define('WPSP_PRO_PLUGIN_PATH', plugin_dir_path(__FILE__));


        // Licensing
        define('WPSP_PRO_STORE_URL', 'https://wpdeveloper.com/');
        define('WPSP_PRO_SL_ITEM_ID', 78593);
        define('WPSP_PRO_SL_ITEM_SLUG', 'wp-scheduled-posts-pro');
        define('WPSP_PRO_SL_ITEM_NAME', 'WP Scheduled Posts');
    }

    /**
     * Initialize the plugin
     *
     * @return void
     */
    public function init_plugin()
    {
        new WPSP_PRO\Assets();
        $this->load_textdomain();
        if (is_admin()) {
            new WPSP_PRO\Admin();
        }
        new WPSP_PRO\Scheduled();
        $this->installer->plugin_updater();
    }

    public function load_textdomain()
    {

        load_plugin_textdomain(
            'wp-scheduled-posts-pro',
            false,
            dirname(dirname(plugin_basename(__FILE__))) . '/languages/'
        );
    }

    public function install_core()
    {
        new WPSP_PRO\Admin\WPDev\InstallCore();
    }

    /**
     * Do stuff upon plugin activation
     *
     * @return void
     */
    public function activate()
    {
        $this->installer->plugin_activation_hook();
        update_option('wpsp_do_activation_redirect', true);
    }
    /**
     * Do stuff upon plugin deactive
     *
     * @return void
     */
    public function deactivate()
    {
        do_action('wpsp_run_deactivate_installer');
    }

    public function run_migrator()
    {
        $this->installer->migrate();
    }
    /**
     * Admin Notices
     */
    public function core_install_notice()
    {
?>
        <div class="error notice is-dismissible">
            <p><strong><?php esc_html_e('SchedulePress Pro', 'wp-scheduled-posts-pro'); ?></strong> <?php esc_html_e('requires', 'wp-scheduled-posts-pro'); ?> <strong><?php esc_html_e('SchedulePress', 'wp-scheduled-posts-pro'); ?></strong> <?php esc_html_e('core plugin to be installed. Please get the plugin now!', 'wp-scheduled-posts-pro'); ?> <button id="wpsp-install-core" class="button button-primary"><?php esc_html_e('Install Now!', 'wp-scheduled-posts-pro') ?></button></p>
        </div>
<?php
    }
}

/**
 * Initializes the main plugin
 *
 * @return \WPSP_PRO
 */
function WPSP_PRO_Start()
{
    return WPSP_PRO::init();
}

// Plugin Start
WPSP_PRO_Start();
